@@ -1,15 +1,17 @@
 import os
 
+from functools import wraps
 from fastapi import FastAPI
 from fastapi.requests import Request
 from fastapi.responses import FileResponse
 from fastapi.middleware.cors import CORSMiddleware
 
 from .routers import relics
-from reliquery import Relic
+from .routers.relics import cache_no_store
+from reliquery import Relic, Reliquery
 
 
-def get_app(Relic=Relic):
+def get_app(Relic=Relic, Reliquery=Reliquery):
     app = FastAPI()
     app.add_middleware(
         CORSMiddleware,
@@ -19,21 +21,27 @@ def get_app(Relic=Relic):
         allow_headers=["*"],
     )
 
-    app.include_router(relics.get_router(Relic), prefix="/api", tags=["relics"])
+    app.include_router(
+        relics.get_router(Relic, Reliquery), prefix="/api", tags=["relics"]
+    )
 
     rel_loc = os.path.dirname(__file__)
-    dist_path = os.path.join(os.path.split(rel_loc)[0], "frontend/dist/")
-    index_path = dist_path + "index.html"
+    dist_path = os.path.normpath(
+        os.path.join(os.path.split(rel_loc)[0], "frontend", "dist")
+    )
+    index_path = os.path.join(dist_path, "index.html")
 
     @app.get("/", response_class=FileResponse)
+    @cache_no_store
     def read_index(request: Request):
         return FileResponse(index_path)
 
     @app.get("/{catchall:path}", response_class=FileResponse)
+    @cache_no_store
     def read_index(request: Request):
         # check first if requested file exists
         path = request.path_params["catchall"]
-        file = dist_path + path
+        file = os.path.join(dist_path, path)
 
         print("looking for: ", path, file)
         if os.path.exists(file):
@@ -45,4 +53,6 @@ def get_app(Relic=Relic):
     return app
 
 
-app = get_app(Relic)
+def create_app():
+    app = get_app()
+    return app
